<!DOCTYPE html>
<html>
<head>
    <meta charset="utf-8">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <title></title>
</head>
<body>
<?php /**PATH /my-work-directory/resources/views/welcome.blade.php ENDPATH**/ ?>
